import { AxiosInstance } from 'axios';
import { API, IFriend } from './api';
import { IOptions, Options } from './options';
import { DataParser } from './parser';
import { RendersContext, ServerContext, SkinContext, CapeContext, PlayerContext, SearchContext, Username, IRendersContextOptions, IContextOptions, ITransformSkinOptions, CapeHash, ICheckServerLikeOptions } from './contexts';
export interface IGetSkinHistoryOptions {
    /**
     * Player username
     */
    username: Username;
    /**
     * Page
     */
    page?: number;
}
export interface IGetSkinsOptions<T extends Tab | TabUnion, S extends Section | SectionUnion, P extends number | undefined = number> {
    /**
     * Tab
     */
    tab?: T;
    /**
     * Section
     */
    section?: S;
    /**
     * Page
     */
    page?: P;
}
export declare enum Tab {
    TRENDING = "trending",
    NEW = "new",
    RANDOM = "random",
    TAG = "tag"
}
export declare type TabUnion = `${Tab}`;
export declare enum Section {
    DAILY = "daily",
    WEEKLY = "weekly",
    MONTHLY = "monthly",
    TOP = "top"
}
export declare type SectionUnion = `${Section}` | string | undefined;
export declare class NameMC extends DataParser {
    #private;
    /**
     * @hidden
     */
    readonly client: AxiosInstance;
    /**
     * Parameters passed to the constructor during class initialization
     */
    readonly options: Options;
    /**
     * Class for API Requests
     */
    readonly api: API;
    constructor(options?: IOptions);
    /**
     * Get skin history by nickname
     */
    skinHistory({ username, page }: IGetSkinHistoryOptions): Promise<SkinContext[]>;
    /**
     * Get player info by nickname
     */
    getPlayer(username: Username): Promise<PlayerContext>;
    /**
     * Get skin renders
     */
    getRenders(options: Omit<IRendersContextOptions, keyof IContextOptions>): RendersContext;
    /**
     * Transform skin method
     */
    transformSkin({ skin, transformation, model }: ITransformSkinOptions): Promise<SkinContext>;
    /**
     * Get cape info by cape hash
     */
    getCapeInfo(hash: CapeHash): CapeContext;
    /**
     * Get player friends by nickname
     */
    getFriends(username: Username): Promise<IFriend[]>;
    /**
     * Get new skins
     *
     * @see {@link https://namemc.com/minecraft-skins/new | NameMC New Skins}
     */
    getSkins(options: IGetSkinsOptions<'new', undefined>): Promise<SkinContext[]>;
    /**
     * Get skins tags
     *
     * @see {@link https://namemc.com/minecraft-skins/tag | NameMC Tagged Skins}
     */
    getSkins(options: IGetSkinsOptions<'tag', undefined>): Promise<SkinContext[]>;
    /**
     * Get skins by tag
     *
     * @see {@link https://namemc.com/minecraft-skins/tag/girl | NameMC Girl Tag Skins}
     */
    getSkins(options: IGetSkinsOptions<'tag', string>): Promise<SkinContext[]>;
    /**
     * Get daily trending skins
     *
     * @see {@link https://namemc.com/minecraft-skins/trending/daily | NameMC Daily Trending Skins}
     */
    getSkins(options: IGetSkinsOptions<'trending', 'daily'>): Promise<SkinContext[]>;
    /**
     * Get weekly trending skins
     *
     * @see {@link https://namemc.com/minecraft-skins/trending/weekly | NameMC Weekly Trending Skins}
     */
    getSkins(options: IGetSkinsOptions<'trending', 'weekly'>): Promise<SkinContext[]>;
    /**
     * Get monthly trending skins
     *
     * @see {@link https://namemc.com/minecraft-skins/trending/monthly | NameMC Monthly Trending Skins}
     */
    getSkins(options: IGetSkinsOptions<'trending', 'monthly'>): Promise<SkinContext[]>;
    /**
     * Get top trending skins
     *
     * @see {@link https://namemc.com/minecraft-skins/trending/top | NameMC Top Trending Skins}
     */
    getSkins(options: IGetSkinsOptions<'trending', 'top'>): Promise<SkinContext[]>;
    /**
     * Get random skins
     *
     * @see {@link https://namemc.com/minecraft-skins/random | NameMC Random Skins}
     */
    getSkins(options: IGetSkinsOptions<'random', undefined>): Promise<SkinContext[]>;
    /**
     * Get information about skin
     */
    getSkin(id: SkinContext['id']): Promise<SkinContext>;
    /**
     * Get servers list
     */
    getServers(page?: number): Promise<ServerContext[]>;
    /**
     * Get server by ip
     */
    getServer(ip: string): Promise<ServerContext>;
    /**
     * Get server likes by ip
     */
    getServerLikes(ip: string): Promise<string[]>;
    /**
     * Check server like value by username
     */
    checkServerLike({ ip, username }: ICheckServerLikeOptions): Promise<boolean>;
    /**
     * Search
     */
    search(query: string): Promise<SearchContext | PlayerContext | ServerContext>;
}
export * from './api';
export * from './contexts';
export * from './options';
export * from './utils';
